==> nui_core-0.0.81.tar.gz: lib/ui/component/listview/nui_header_staggered_list.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter_staggered_grid_view/flutter_staggered_grid_view.dart';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_core/data/nui_data_util.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_core/ui/component/listview/nui_list_item_repo.dart';
import 'package:nui_core/ui/component/listview/nui_listview_bloc.dart';
import 'nui_list_interface.dart';
import 'nui_listview_builder.dart';
import 'nui_listview_functions.dart';

class NUIHeaderStaggeredList<T, C> extends NUIAnimatedListInterface<T, C> {
  NUIHeaderStaggeredList({
    this.header,
    @required NUIListViewBloc<T, C> bloc,
    @required NUIListItemRepository repo,
    @required List<T> initialList,
    @required OnListItemClickListener clickListener,
    bool shrinkWrap: false,
    double startDivider,
    double endDivider,
    double middleDivider,
    ListFixedItemGetter fixedFirstItem,
    ListFixedItemGetter fixedLastItem,
    Axis orientation: Axis.vertical,
    EdgeInsets padding,
    bool enablePagination: false,
    bool enableSwipeRefresh: false,
    int minimumPaginateCount: 5,
    NUILoadingListItem skeletalInflater,
    NUILoadingListItem paginationInflater,
    ListShadowInflater shadowInflater,
    ListPlaceHolderInflater placeHolder,
    ListErrorHolderInflater errorHolder,
    int skeletalCount: 1,
    NUIShaderMaskType shaderType,
    NUIListController controller,
    NUIListScrollListener scrollListener,
    ScrollPhysics scrollPhysics,
    Map<String, dynamic> checkedMap,
    Map<String, dynamic> configMap,
    this.mainAxisSpacing : 0,
    this.crossAxisSpacing : 0,
    this.withOverlapsAbsorber: false,
  }) : super(
      repo: repo,
      initialList: initialList,
      orientation: orientation,
      padding: padding,
      shrinkWrap: shrinkWrap,
      startDivider: startDivider,
      endDivider: endDivider,
      middleDivider: middleDivider,
      fixedFirstItem: fixedFirstItem,
      fixedLastItem: fixedLastItem,
      checkedMap: checkedMap,
      configMap: configMap,
      clickListener: clickListener,
      skeletalCount: skeletalCount,
      errorHolder: errorHolder,
      placeHolder: placeHolder,
      scrollListener: scrollListener,
      shaderType: shaderType,
      skeletalInflater: skeletalInflater,
      paginationInflater: paginationInflater,
      scrollPhysics: scrollPhysics,
      enablePagination: enablePagination,
      enableSwipeRefresh: enableSwipeRefresh,
      minimumPaginateCount: minimumPaginateCount,
      bloc: bloc,
      skipAnimation: true,
      controller: controller,
      itemAnimation : NUIListItemAnimation.NONE
  );
  final Widget header;
  final bool withOverlapsAbsorber;
  final double mainAxisSpacing;
  final double crossAxisSpacing;

  @override
  _NUIHeaderStaggeredListState<T, C> createState() => _NUIHeaderStaggeredListState<T, C>();
}

class _NUIHeaderStaggeredListState<T, C> extends NUIAnimatedListState<T, C, NUIHeaderStaggeredList<T, C>> {
  final String id = randomUUID();

  double _getItemRatio(int position){
    final data = items.getOrNull(position);
    NUIListItem item = repo().getItemByClass(data.runtimeType);
    if(item.heightToWidthRatio == null) return 1.0;
    return item.heightToWidthRatio(data, position);
  }

  @override
  Widget getListView(int initialCount) {
    logNUI("NUIHeaderStaggeredList", "Building animated header list view");

    Widget sliverList;
    if(!curModel.isLoading() && curModel.success == false && isNullOrEmpty(curModel.data) && widget.errorHolder != null){
      sliverList = SliverToBoxAdapter(child: widget.errorHolder(curModel));
    }
    else if(!curModel.isLoading() && isNullOrEmpty(curModel.data) && widget.placeHolder != null){
      sliverList = SliverToBoxAdapter(child: widget.placeHolder());
    }
    else {
      sliverList = SliverPadding(
          padding: widget.padding != null ? widget.padding : EdgeInsets.all(0),
          sliver : StaggeredGridView.countBuilder(
            crossAxisCount: 3,
            itemCount: 20,
            itemBuilder: (BuildContext context, int position) {
              if (position < items.length) {
                return renderItem(context, position);
              }
              return null;
            },
            staggeredTileBuilder: (index){
              return StaggeredTile.count(1, _getItemRatio(index));
            },
            mainAxisSpacing: widget.mainAxisSpacing ?? 0,
            crossAxisSpacing: widget.crossAxisSpacing ?? 0,
          )
      );
    }

    final slivers = List<Widget>();
    if(widget.header != null) {
      slivers.add(SliverToBoxAdapter(child: widget.header,),);
    }
    slivers.add(sliverList);

    Widget scrollView;
    if(widget.withOverlapsAbsorber == true) {
      logNUI("NUIHeaderStaggeredList", "With overlaps absorber enabled, wrapping list with SliverOverlapInjector");
      scrollView = Builder(
        builder: (BuildContext context) {
          final innerSlivers = List<Widget>();
          innerSlivers.add(SliverOverlapInjector(
            handle: NestedScrollView.sliverOverlapAbsorberHandleFor(context),
          ));
          innerSlivers.addAll(slivers);

          return CustomScrollView(
              physics: widget.scrollPhysics ?? NUICustomScrollPhysics(),
              scrollDirection: orientation(),
              key: PageStorageKey<String>(id),
              slivers: innerSlivers
          );
        },
      );
    }
    else {
      scrollView = CustomScrollView(
          physics: widget.scrollPhysics ?? NUICustomScrollPhysics(),
          scrollDirection: orientation(),
//        controller: scrollController(),
          slivers: slivers
      );
    }
    return scrollView;
  }

}

==> nui_core-0.0.85.tar.gz: lib/ui/component/listview/nui_header_staggered_list.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter_staggered_grid_view/flutter_staggered_grid_view.dart';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_core/data/nui_data_util.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_core/ui/component/listview/nui_list_item_repo.dart';
import 'package:nui_core/ui/component/listview/nui_listview_bloc.dart';
import 'nui_list_interface.dart';
import 'nui_listview_builder.dart';
import 'nui_listview_functions.dart';


class NUIHeaderStaggeredList<T, C> extends NUIAnimatedListInterface<T, C> {
  NUIHeaderStaggeredList({
    this.header,
    @required NUIListViewBloc<T, C> bloc,
    @required NUIListItemRepository repo,
    @required List<T> initialList,
    @required OnListItemClickListener clickListener,
    bool shrinkWrap: false,
    double startDivider,
    double endDivider,
    double middleDivider,
    ListFixedItemGetter fixedFirstItem,
    ListFixedItemGetter fixedLastItem,
    Axis orientation: Axis.vertical,
    EdgeInsets padding,
    bool enablePagination: false,
    bool enableSwipeRefresh: false,
    int minimumPaginateCount: 5,
    NUILoadingListItem skeletalInflater,
    NUILoadingListItem paginationInflater,
    ListShadowInflater shadowInflater,
    ListPlaceHolderInflater placeHolder,
    ListErrorHolderInflater errorHolder,
    int skeletalCount: 1,
    NUIShaderMaskType shaderType,
    NUIListController controller,
    NUIListScrollListener scrollListener,
    ScrollPhysics scrollPhysics,
    Map<String, dynamic> checkedMap,
    Map<String, dynamic> configMap,
    this.mainAxisSpacing : 0,
    this.crossAxisSpacing : 0,
    this.crossAxisCount: 1,
    this.withOverlapsAbsorber: false,
  }) : super(
      repo: repo,
      initialList: initialList,
      orientation: orientation,
      padding: padding,
      shrinkWrap: shrinkWrap,
      startDivider: startDivider,
      endDivider: endDivider,
      middleDivider: middleDivider,
      fixedFirstItem: fixedFirstItem,
      fixedLastItem: fixedLastItem,
      checkedMap: checkedMap,
      configMap: configMap,
      clickListener: clickListener,
      skeletalCount: skeletalCount,
      errorHolder: errorHolder,
      placeHolder: placeHolder,
      scrollListener: scrollListener,
      shaderType: shaderType,
      skeletalInflater: skeletalInflater,
      paginationInflater: paginationInflater,
      scrollPhysics: scrollPhysics,
      enablePagination: enablePagination,
      enableSwipeRefresh: enableSwipeRefresh,
      minimumPaginateCount: minimumPaginateCount,
      bloc: bloc,
      skipAnimation: true,
      controller: controller,
      itemAnimation : NUIListItemAnimation.NONE
  );
  final Widget header;
  final bool withOverlapsAbsorber;
  final double mainAxisSpacing;
  final double crossAxisSpacing;
  final int crossAxisCount;

  @override
  _NUIHeaderStaggeredListState<T, C> createState() => _NUIHeaderStaggeredListState<T, C>();
}

class _NUIHeaderStaggeredListState<T, C> extends NUIAnimatedListState<T, C, NUIHeaderStaggeredList<T, C>> {
  final String id = randomUUID();

  double _getItemRatio(int position){
    final data = items.getOrNull(position);
    NUIListItem item = repo().getItemByClass(data.runtimeType);
    if(item.heightToWidthRatio == null) return 1.0;
    return item.heightToWidthRatio(data, position);
  }

  @override
  Widget getListView(int initialCount) {
    logNUI("NUIHeaderStaggeredList", "Building animated header list view");

    Widget sliverList;
    bool isList = false;
    if (!curModel.isLoading() && curModel.success == false &&
        isNullOrEmpty(curModel.data) && widget.errorHolder != null) {
      sliverList = SliverToBoxAdapter(child: widget.errorHolder(curModel));
    }
    else if (!curModel.isLoading() && isNullOrEmpty(curModel.data) &&
        widget.placeHolder != null) {
      sliverList = SliverToBoxAdapter(child: widget.placeHolder());
    }
    else {
      isList = true;
      sliverList = StaggeredGridView.countBuilder(
        crossAxisCount: widget.crossAxisCount ?? 2,
        itemCount: items.length,
        itemBuilder: (BuildContext context, int position) {
          if (position < items.length) {
            return renderItem(context, position);
          }
          return null;
        },
        staggeredTileBuilder: (index) {
          return StaggeredTile.count(1, _getItemRatio(index));
        },
        mainAxisSpacing: widget.mainAxisSpacing ?? 0,
        crossAxisSpacing: widget.crossAxisSpacing ?? 0,
      );
    }

    final slivers = List<Widget>();
//    if(widget.header != null) {
//      slivers.add(SliverToBoxAdapter(child: widget.header,),);
//    }
    slivers.add(sliverList);

    if (isList != true){
      return CustomScrollView(
        physics: widget.scrollPhysics ?? NUICustomScrollPhysics(),
        scrollDirection: orientation(),
        key: PageStorageKey<String>(id),
        slivers: slivers
      );
    }
    else {
      return sliverList;
    }
  }
}
